<template>
  <div>
    <el-dialog :visible.sync="dialogVisible" @close="$emit('close')" :title="row.userId ? '编辑人员' : '添加人员'" width="30%">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="姓名" prop="nickName">
          <el-input v-model="form.nickName" placeholder="请输入" style="width: 50%"></el-input>
        </el-form-item>
        <el-form-item label="联系电话" prop="phonenumber">
          <el-input v-model="form.phonenumber" placeholder="请输入" style="width: 50%"></el-input>
        </el-form-item>
        <el-form-item label="登陆账号" prop="userName">
          <div style="display: flex; align-items: center">
            <el-input v-model="form.userName" :disabled="form.userId" placeholder="请输入" style="width: 50%"></el-input>
            <div style="margin-left: 10px; color: red">登录账号不可重复</div>
          </div>
        </el-form-item>
        <el-form-item label="角色" prop="roleId">
          <el-select v-model="form.roleId" placeholder="请选择（单选）">
            <el-option v-for="item in roleList" :key="item.roleId" :label="item.roleName"
              :value="item.roleId"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="启动状态" prop="status">
          <el-switch v-model="form.status"></el-switch>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input type="textarea" v-model="form.remark" placeholder="请输入" style="width: 50%"></el-input>
        </el-form-item>
      </el-form>
      <div class="select-member-footer">
        <el-button @click="$emit('close')">关闭</el-button>
        <el-button type="primary" @click="submit">保存</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
export default {
  props: {
    dialogVisible: {
      type: Boolean,
      default: false,
    },
    row: {
      type: Object,
      default: () => { },
    },
    roleList: {
      type: Array,
      default: () => [],
    },
    deptType: {
      type: Array,
      default: () => [],
    },
  },
  data() {
    var validatePhone = (rule, value, callback) => {
      if (!value) {
        // The 'required' rule will handle empty value, so we can make this optional here
        // or keep it for a more specific message if needed.
        // For now, let's assume 'required' handles the empty case.
        callback();
        return;
      }
      const phoneRegex = new RegExp(/^(13[0-9]|14[01456879]|15[0-35-9]|16[2567]|17[0-8]|18[0-9]|19[0-35-9])\d{8}$/,'g'); // Regex for 11-digit Chinese mobile numbers
      if (!phoneRegex.test(value)) {
        callback(new Error('请输入有效的11位手机号码'));
      } else {
        callback();
      }
    };
    return {
      form: { status: true },
      userDeptId: '',
      rules: {
        nickName: [{ required: true, message: '请输入姓名', trigger: 'blur' }],
        phonenumber: [
          { required: true, message: '请输入联系电话', trigger: 'blur' },
          { validator: validatePhone, trigger: 'blur' }
        ],
        roleId: [{ required: true, message: '请选择角色', trigger: 'change' }],
        userName: [{ required: true, message: '请输入登陆账号', trigger: 'blur' }],
        status: [{ required: true, message: '请选择启动状态', trigger: 'blur' }],
      },
    }
  },
  created() {
    if (this.row && this.row.userId) {
      this.form = {
        ...this.row,
        status: this.row.status == 0 ? true : false,
      }
    } else {
      this.form = {
        nickName: '',
        phonenumber: '',
        userName: '',
        roleId: '',
        status: true,
        remark: '',
      }
    }
  },
  mounted() { },
  methods: {
    submit() {
      this.$refs['form'].validate((valid) => {
        if (valid) {
          let obj = {
            ...this.form,
            status: this.form.status ? 0 : 1,
          }
          this.$emit('confirm', obj)
        }
      })
    },
  },
}
</script>
<style scoped></style>